"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BabelConfigReader = void 0;
const fs = require("fs");
const path = require("path");
const plugin_1 = require("@stryker-mutator/api/plugin");
let BabelConfigReader = /** @class */ (() => {
    class BabelConfigReader {
        constructor(log) {
            this.log = log;
        }
        readConfig(strykerOptions) {
            const babelConfig = Object.assign({}, strykerOptions.babel);
            babelConfig.options = Object.assign(Object.assign({}, this.readBabelOptionsFromFile(babelConfig.optionsFile)), babelConfig.options);
            this.log.debug(`Babel config is: ${JSON.stringify(babelConfig, null, 2)}`);
            return babelConfig;
        }
        readBabelOptionsFromFile(relativeFileName) {
            if (relativeFileName) {
                const babelrcPath = path.resolve(relativeFileName);
                this.log.debug(`Reading .babelrc file from path "${babelrcPath}"`);
                if (fs.existsSync(babelrcPath)) {
                    try {
                        if (path.basename(babelrcPath) === '.babelrc.js') {
                            return require(babelrcPath);
                        }
                        if (path.basename(babelrcPath) === 'babel.config.js') {
                            const config = require(babelrcPath);
                            if (typeof config === 'function') {
                                const configFunction = config;
                                return configFunction(noopBabelConfigApi);
                            }
                            else {
                                return config;
                            }
                        }
                        return JSON.parse(fs.readFileSync(babelrcPath, 'utf8'));
                    }
                    catch (error) {
                        this.log.error(`Error while reading "${babelrcPath}" file: ${error}`);
                    }
                }
                else {
                    this.log.error(`babelrc file does not exist at: ${babelrcPath}`);
                }
            }
            return {};
        }
    }
    BabelConfigReader.inject = plugin_1.tokens(plugin_1.commonTokens.logger);
    return BabelConfigReader;
})();
exports.BabelConfigReader = BabelConfigReader;
function noop() { }
const noopBabelConfigApi = {
    assertVersion() {
        return true;
    },
    cache: {
        forever: noop,
        invalidate() {
            return noop;
        },
        never: noop,
        using() {
            return noop;
        },
    },
    env: noop,
    caller: noop,
    version: noop,
};
//# sourceMappingURL=BabelConfigReader.js.map